import moment from "moment"

/**
 * 获取今天是今年的第几周，格式为 YYYY-WW。
 * @returns {string} 今天是今年的第几周。
 */
export const getWeekTimeWithYear = (): string => {
  return moment().format("YYYY-WW")
}

/**
 * 获取上周是今年的第几周，格式为 YYYY-WW。
 * @returns {string} 上周是今年的第几周。
 */
export const getPrevWeekWithYear = (): string => {
  return moment().subtract(1, "weeks").format("YYYY-WW")
}

/**
 * 将秒数转换为分钟，保留一位小数。
 * @param {number} sec - 秒数。
 * @returns {string} 转换后的分钟数，保留一位小数。
 */
export const sec2min = (sec: number): string => {
  return (sec / 60).toFixed(1)
}

/**
 * 将秒数转换为分钟和秒数，格式为 Xm Ys。
 * @param {number} sec - 秒数。
 * @returns {string} 转换后的分钟和秒数，格式为 Xm Ys。
 */
export const sec2minStr = (sec: number): string => {
  const min = Math.floor(sec / 60)
  const s = sec % 60
  return `${min}m ${s}s`
}
